#
# spec file for package czmq
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_name libczmq4
Name:           czmq
Version:        4.2.1
Release:        1.15
Summary:        High-level C binding for ZeroMQ
License:        MPL-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/zeromq/czmq
Source0:        https://github.com/zeromq/czmq/releases/download/v%{version}/czmq-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libcurl-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libzmq) > 4.1
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(uuid)
# documentation
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  xz

%description
CZMQ is a higher-level binding for the ZeroMQ core API.
This package contains key creation utility zmakecert.

%package -n %{lib_name}
Summary:        Shared library of %{name}
Group:          Development/Languages/C and C++

%description -n %{lib_name}
CZMQ is a higher-level binding for the ZeroMQ core API.

* It wraps the ZeroMQ core API in semantics that lead to shorter,
  more readable applications.
* It hides, as far as possible, the differences between different
  versions of ZeroMQ (2.x, 3.x, 4.x).
* It provides a space for development of more sophisticated API
  semantics.
* It wraps the ZeroMQ security features with high-level tools and
  APIs.
* It is the basis for other language bindings built on top of CZMQ.

%package devel
Summary:        Devel files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Requires:       systemd-devel
Requires:       pkgconfig(liblz4)
Requires:       pkgconfig(uuid)

%description devel
CZMQ is a higher-level binding for the ZeroMQ core API.

This subpackage contains libraries, header files, and pkgconfig and
cmake descriptions for developing applications that want to make use
of CZMQ.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

rm -f %{buildroot}/%{_bindir}/*.gsl
rm -f %{buildroot}/%{_libdir}/*.la

%post -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files
%license LICENSE
%{_bindir}/zmakecert
%{_mandir}/man1/zmakecert.1.gz

%files -n %{lib_name}
%{_libdir}/libczmq.so.*

%files devel
%license LICENSE
%doc AUTHORS CONTRIBUTING.md NEWS README.md README.txt
%{_includedir}/*.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_mandir}/man3/z*.3.gz
%{_mandir}/man7/%{name}.7.gz
%dir %{_datadir}/zproject
%{_datadir}/zproject/%{name}

%changelog
* Fri Mar  5 2021 Dirk Müller <dmueller@suse.com>
- update to 4.2.1:
  * New DRAFT zsock API to match libzmq's 4.3.4 socket options:
  - zsock_set_xpub_manual_last_value
  - zsock_socks_username, zsock_set_socks_username
  - zsock_socks_password, zsock_set_socks_password
  - zsock_in_batch_size, zsock_set_in_batch_size
  - zsock_out_batch_size, zsock_set_out_batch_size
  - zsock_set_wss_key_pem, zsock_set_wss_cert_pem, zsock_set_wss_trust_pem,
    zsock_set_wss_hostname, zsock_set_wss_trust_system
  - zsock_set_only_first_subscribe
  - zsock_hello_msg, zsock_set_hello_msg
  - zsock_disconnect_msg, zsock_set_disconnect_msg
  - zsock_priority, zsock_set_priority
  - zsock_reconnect_stop, zsock_set_reconnect_stop
    See zsock manpage for more details.
  * New DRAFT zframe and zmsg API to print arbitrary length messages:
  - zframe_print_n
  - zmsg_print_n
    See zframe and zmsg manpages for more details.
  * New DRAFT zosc* APIs to support the OSC (Open Sound Control) protocol.
    See zosc_* manpages for more details.
  * New DRAFT zcertstore_get_state API to get the state stored in the certstore.
    See the zcertstore manpage for more details.
  * Support for new libzmq DRAFT socket type ZMQ_DGRAM was added to zsock.
  * Fixed #1972 - Findlibzmq.cmake out of date, Windows build fails
  * Fixed #1998 - zproxy uses fixed ipc endpoint, causing race condition
  * Fixed #2002 - fix socket leak in zbeacon
  * Fixed #2020 - use libnss in zdigest if available for SHA functions.
  * Fixed #2028 - zpoller docs isn't mentioning file handles
  * Fixed #2043 - zhttp_response_recv leaks memory when result is non-zero
  * Fixed #2045 - Problem: zframe_print output is truncated
  * Fixed #2048 - no logging if zsys is not initialized
  * Fixed #2057 - zchunk_slurp() causes assert if file can't be opened
  * Fixed #2062 - allow zbeacon to resolve ip address to interface or interface
  * Fixed #2064 - Enable ipv4 multicast packet types when using zbeacon
  * Fixed #2072 - fix build on Android NDK >= 24
  * Fixed #2086 - zsys is re-initialized when logging an error in zsys_shutdown
  * Fixed #2090 - "quit" variable in zproc_wait() can overflow
  * Fixed #2087 - logsender destroyed before last log message
  * Fixed #2103 - if gossip server disconnects and reconnects, persisting gossip
  * Fixed #2113 - zcertstore has no API to get the disk state from a custom loader
  * Fixed #2115 - various issues around zcertstore API string ownership
  * Fixed #2038 - zsock_t sockets do not work in child process after fork
  * Fixed #2144 - zhashx_dup() does not copy callbacks
- build against systemd, uuid, nss and related
* Wed Sep  9 2020 Adam Majer <adam.majer@suse.de>
- Move the manpage for the tool to the package with the tool
* Mon Mar 18 2019 mvyskocil@opensuse.org
- Update to 4.2.0
  - New STABLE APIs
  * zsys_thread_name_prefix, zsys_set_thread_name_prefix
  * zsys_thread_affinity_cpu_add, zsys_thread_affinity_cpu_remove
  * zsock_bindtodevice, zsock_set_bindtodevice
  * zsock_gssapi_service_principal_nametype, zsock_set_gssapi_service_principal_nametype
  * zsock_gssapi_principal_nametype, zsock_set_gssapi_principal_nametype
  - Bugfixes
  * #1899 - zsys_udp_new leaks file descriptor when process is exec'd.
  * #1948 - zlistx_head always returns NULL.
  * #1959 - zhash_pack crash on armv7 due to unaligned pointer access.
  * #1961 - unnecessary uuid includes in public headers break builds without
    libuuid.
  * #1995 - timers are called twice if they change the pollset.
  - A lot of changes in DRAFT apis, see NEWS
* Wed Apr 18 2018 mvyskocil@opensuse.org
- Update to 4.1.1, bugfixes:
  * Fixed #1847 - fix test segfault when no USER env variable exists
  * Fixed #1848 - fix zsock_resolve when using many thousands of sockets
  * Fixed #1875 - fix build with GCC 8
  * Fixed #1876 - fix crash in zsys_shutdown with libzmq 4.2.4 built with
    Tweetnacl
- A lot of changes in DRAFT apis, see NEWS
* Tue Jan  2 2018 adam.majer@suse.de
- Update to 4.1.0
  * New STABLE APIs have been added to wrap new libzmq context
    options:
    + zsys_set_thread_sched_policy
    + zsys_set_thread_priority
  * See https://github.com/zeromq/czmq/releases/tag/v4.1.0
    for complete changelog.
- Remove patches now in upstream sources:
  * 0000-gcc7-b651cb47.patch
  * 0001-gcc7-41866333e.patch
* Mon Jun  5 2017 mvyskocil@opensuse.org
-  Fix a build with gcc7
-  Add:
  * 0000-gcc7-b651cb47.patch
  * 0001-gcc7-41866333e.patch
* Sat Dec 31 2016 adam.majer@suse.de
- Update to 4.0.2
  * Fixed DRAFT zsock_new_*_checked symbols leak
  * Fixed zsock options could be available at build time but
    not at runtime. Added runtime check, an error will
    be printed if the option is not available.
  * Fixed improved compatibility with Solaris/Illumos
  * Fixed memory leak when message send fails in internal usage
- Update to 4.0.1
  * Version 4.0.0 introduced the DRAFT mechanism, but it had a
    flaw: the internally defined DRAFT symbols were leaking as
    global in the shared library. This meant that although the API
    was stable, the ABI could in some cases not be. This has now
    been fixed using compiler's visibility attribute to avoid this
    problem.
* Sat Nov  5 2016 jengelh@inai.de
- Update descriptions
* Sat Nov  5 2016 mvyskocil@opensuse.org
- Update to 4.0.0
  * v4.0.0 breaks API and ABI compatibility with v3.0.2.
    The ABI version has been bumped to 4.
  * The v2 API, which have been declared DEPRECATED in v3.0.0
    released on 2014/10/15, have now been declared RETIRED
    and removed from this release. The following classes are gone:
    zauth_v2, use zauth
    zbeacon_v2, use zbeacon
    zctx, use zsock
    zmonitor_v2, use zmonitor
    zmutex
    zproxy_v2, use zproxy
    zsocket, use zsock
    zsockopt, use zsock
    zthread, use zactor
  * see NEWS file for more details
* Wed Oct 12 2016 mvyskocil@opensuse.org
- add 0001-readdir_r-deprecated.patch to fix a build in Tumbleweed
* Tue Jul  7 2015 mvyskocil@opensuse.org
- Do not install makecert to workaround the conflict between
  czmq and mono-devel
* Tue Jul  7 2015 mvyskocil@opensuse.org
- Correct License tag to MPL-2.0
* Thu Jul  2 2015 mvyskocil@opensuse.org
- Update to 3.0.2
  * https://github.com/zeromq/czmq/issues/1021
* Mon Jun  8 2015 mvyskocil@opensuse.org
- Update to 3.0.1
  * New zsock class that works without contexts, and has smart
  constructors (create and connect/bind in one step).
  * New zactor class for multithreaded development, evolved from
  old zthread attached threads.
  * New zgossip discovery service.
  * New zrex class for regular expressions.
  * New process management functions in zsys.
- These V2 classes are deprecated:
  * zauth (rewritten as actor)
  * zbeacon (rewritten as actor)
  * zctx (deprecated)
  * zmonitor (rewritten as actor)
  * zmutex (deprecated)
  * zproxy (rewritten as actor)
  * zsocket (deprecated by zsock)
  * zsockopt (deprecated by zsock_option)
  * zthread (deprecated by zactor)
* Tue Jan 27 2015 mvyskocil@opensuse.org
- Update to 3.0.0~git.1422214591.ab92619, bugfixes
* Fri Jan 16 2015 jengelh@inai.de
- Request xz package for rpm, since source is xz archive.
* Thu Jan  8 2015 mvyskocil@opensuse.org
- Need libzmq >= 4.2, needed for malamute broker
* Thu Jan  8 2015 mvyskocil@opensuse.org
- Update to czmq-3.0.0~git.1420493785.71863a3
  * add zlistx/zhashx to provide better API than existing zlist/shash
  * czmq_selftest is no longer installed
  * remove internal usage of deprecated zsocket
  * regenerates zgossip engine/codec using latest zproto
  * speedup of zsock_send/recv
  * add move NULL checks, memory leak fixes and so
* Tue Nov  4 2014 mvyskocil@opensuse.org
- Update to czmq-3.0.0~git.1415022110.59a4f16
  * add zclock_usecs at least
* Thu Oct 16 2014 mvyskocil@opensuse.org
- Update to rc version of 3.0.0 3.0.0~git.1413364181.4d79b31
* Thu Sep 18 2014 mvyskocil@opensuse.org
- Initial packaging of czmq for openSUSE
